package com.ekexiu.project.department;

import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.util.PageQueryResult;
import org.jfw.util.jdbc.JdbcUtil;
import org.jfw.util.jdbc.PreparedStatementConfig;
import org.jfw.util.jdbc.ResultSetExtractor;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by TT on 2019/5/30.
 */
@Path("/department")
public class DepartmentService {

    @Autowrie
    private DepartmentDao departmentDao;

    public DepartmentDao getDepartmentDao() {
        return departmentDao;
    }

    public void setDepartmentDao(DepartmentDao departmentDao) {
        this.departmentDao = departmentDao;
    }

    @Path("/qo")
    @Get
    public Department query(@JdbcConn Connection con, String id) throws SQLException {
        return departmentDao.query(con, id);
    }

    @Path("/pq")
    @Get
    public PageQueryResult<Department> pageQuery(@JdbcConn Connection con, @Nullable Boolean active, @Nullable String name, int pageSize, int pageNo) throws SQLException {
        return departmentDao.pageQuery(con, active, name == null ? null : "%" + name + "%", pageSize, pageNo);
    }

    @Path("/hospital")
    @Get
    public List<Department> listQuery(@JdbcConn Connection con, @Nullable Boolean active, String hospital) throws SQLException {
        return departmentDao.listQuery(con, hospital, active);
    }

    @Path("/classify")
    @Get
    public List<Map<String, Object>> classify(@JdbcConn Connection con, final Boolean active, String hospital) throws SQLException {
        final String finalkey = hospital;
        List<Map<String, Object>> result = JdbcUtil.queryList(con, "select id,name,type from department where hospital = ? and active = ?", new ResultSetExtractor<Map<String, Object>>() {
            @Override
            public Map<String, Object> extractData(ResultSet resultSet) throws SQLException {
                Map<String, Object> map = new HashMap<>();
                map.put("id", resultSet.getInt(1));
                map.put("name", resultSet.getInt(2));
                map.put("type", resultSet.getInt(3));
                return map;
            }
        }, new PreparedStatementConfig() {
            @Override
            public void config(PreparedStatement preparedStatement) throws SQLException {
                preparedStatement.setString(1, finalkey);
                preparedStatement.setBoolean(2, active);
            }
        });

        for (Map<String, Object> map : result) {
            final String id = (String) map.get("id");
            map.put("num", JdbcUtil.queryInt(con, "select count(*) from doctor where hospital = ? and department = ? and active = ?", new PreparedStatementConfig() {
                @Override
                public void config(PreparedStatement preparedStatement) throws SQLException {
                    preparedStatement.setString(1, finalkey);
                    preparedStatement.setString(2, id);
                    preparedStatement.setBoolean(3, active);
                }
            }, 0));
        }
        return result;
    }

    @Path("/name")
    @Get
    public List<TypeaheadItem> queryName(@JdbcConn Connection con, String name, int size) throws SQLException {
        if (name != null) {
            name = "%" + name + "%";
        }
        List<TypeaheadItem> ret = new ArrayList<>(size);
        final String finalKey = name;
        List<Map<String, Object>> typehead = JdbcUtil.queryMaps(con, "SELECT NAME,ID FROM DEPARTMENT WHERE NAME LIKE ? ", new PreparedStatementConfig() {
            @Override
            public void config(PreparedStatement preparedStatement) throws SQLException {
                preparedStatement.setString(1, finalKey);
            }
        });

        for (Map<String, Object> map : typehead) {
            TypeaheadItem item = new TypeaheadItem();
            item.setId((String) map.get("id"));
            item.setName((String) map.get("name"));
            ret.add(item);
        }
        return ret;
    }


    public static class TypeaheadItem {
        private String id;
        private String name;

        public String getId() {
            return id;
        }

        public void setId(String id) {
            this.id = id;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

    }

}
