package com.ekexiu.project.doctor;


import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.util.PageQueryResult;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * Created by TT on 2019/5/30.
 */
@Path("/doctor")
public class DoctorService {

    @Autowrie
    private DoctorDao doctorDao;

    public DoctorDao getDoctorDao() {
        return doctorDao;
    }

    public void setDoctorDao(DoctorDao doctorDao) {
        this.doctorDao = doctorDao;
    }


    @Get
    @Path("/qo")
    public SessionDoctor query(@JdbcConn Connection con, String id) throws SQLException {
        return makeSessionDoctor(doctorDao.query(con, id));
    }

    @Get
    @Path("/pq")
    public PageQueryResult<SessionDoctor> pageQuery(@JdbcConn Connection con, @Nullable Boolean active, @Nullable String addr, @Nullable String clinicalTitle, @Nullable String level, @Nullable String key, int pageSize, int pageNo) throws SQLException {
        PageQueryResult<Doctor> pageQueryResult =  doctorDao.pageQuery(con, active, addr == null ? null : addr + "%", clinicalTitle, level, key == null ? null : "%" + key + "%", pageSize, pageNo);
        if (pageQueryResult != null) {
            List<Doctor> doctors = pageQueryResult.getData();
            List<SessionDoctor> sessionDoctors = new ArrayList<>();
            if (!doctors.isEmpty()) {
                for (Doctor doctor : doctors) {
                    sessionDoctors.add(makeSessionDoctor(doctor));
                }
                PageQueryResult<SessionDoctor> ret = new PageQueryResult<>();
                ret.setPageNo(pageQueryResult.getPageNo());
                ret.setPageSize(pageQueryResult.getPageSize());
                ret.setTotal(pageQueryResult.getTotal());
                ret.setData(sessionDoctors);
                return ret;
            }
        }
        return null;
    }

    @Path("/hospital")
    @Get
    public PageQueryResult<SessionDoctor> pageQuery(@JdbcConn Connection con, @Nullable Boolean active, String hospital, int pageSize, int pageNo) throws SQLException {
        PageQueryResult<Doctor> pageQueryResult =  doctorDao.pageQuery(con, hospital, active, pageSize, pageNo);
        if (pageQueryResult != null) {
            List<Doctor> doctors = pageQueryResult.getData();
            List<SessionDoctor> sessionDoctors = new ArrayList<>();
            if (!doctors.isEmpty()) {
                for (Doctor doctor : doctors) {
                    sessionDoctors.add(makeSessionDoctor(doctor));
                }
                PageQueryResult<SessionDoctor> ret = new PageQueryResult<>();
                ret.setPageNo(pageQueryResult.getPageNo());
                ret.setPageSize(pageQueryResult.getPageSize());
                ret.setTotal(pageQueryResult.getTotal());
                ret.setData(sessionDoctors);
                return ret;
            }
        }
        return null;
    }

    @Path("/department")
    @Get
    public PageQueryResult<SessionDoctor> pageQuery(@JdbcConn Connection con, @Nullable Boolean active, String hospital, String department, int pageSize, int pageNo) throws SQLException {
        PageQueryResult<Doctor> pageQueryResult = doctorDao.pageQuery(con, hospital, department, active, pageSize, pageNo);
        if (pageQueryResult != null) {
            List<Doctor> doctors = pageQueryResult.getData();
            List<SessionDoctor> sessionDoctors = new ArrayList<>();
            if (!doctors.isEmpty()) {
                for (Doctor doctor : doctors) {
                    sessionDoctors.add(makeSessionDoctor(doctor));
                }
                PageQueryResult<SessionDoctor> ret = new PageQueryResult<>();
                ret.setPageNo(pageQueryResult.getPageNo());
                ret.setPageSize(pageQueryResult.getPageSize());
                ret.setTotal(pageQueryResult.getTotal());
                ret.setData(sessionDoctors);
                return ret;
            }
        }
        return null;
    }

    private static SessionDoctor makeSessionDoctor(Doctor doctor) {
        SessionDoctor sessionDoctor = new SessionDoctor();
        sessionDoctor.setAccount(doctor.getAccount());
        sessionDoctor.setName(doctor.getName());
        sessionDoctor.setHospital(doctor.getHospital());
        sessionDoctor.setDepartment(doctor.getDepartment());
        sessionDoctor.setId(doctor.getId());
        sessionDoctor.setClinicalTitle(doctor.getClinicalTitle());
        sessionDoctor.setTeachTitle(doctor.getTeachTitle());
        sessionDoctor.setPosition(doctor.getPosition());
        sessionDoctor.setDirection(doctor.getDirection());
        sessionDoctor.setDescp(doctor.getDescp());
        sessionDoctor.setImage(doctor.getImage());
        sessionDoctor.setActive(doctor.isActive());
        sessionDoctor.setCreateTime(doctor.getCreateTime());
        sessionDoctor.setModifyTime(doctor.getModifyTime());
        sessionDoctor.setCreator(doctor.getCreator());
        sessionDoctor.setModifier(doctor.getModifier());
        return sessionDoctor;
    }
}
