package com.ekexiu.project.hospital;

import com.ekexiu.project.system.vo.SessionHospital;
import org.jfw.apt.annotation.Autowrie;
import org.jfw.apt.annotation.Nullable;
import org.jfw.apt.web.annotation.Path;
import org.jfw.apt.web.annotation.operate.Get;
import org.jfw.apt.web.annotation.param.JdbcConn;
import org.jfw.util.PageQueryResult;
import org.jfw.util.jdbc.JdbcUtil;
import org.jfw.util.jdbc.ResultSetExtractor;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by TT on 2019/6/5.
 */
@Path("/hospital")
public class HospitalService {

    @Autowrie
    private HospitalDao hospitalDao;

    public HospitalDao getHospitalDao() {
        return hospitalDao;
    }

    public void setHospitalDao(HospitalDao hospitalDao) {
        this.hospitalDao = hospitalDao;
    }

    @Path("/qo")
    @Get
    public SessionHospital query(@JdbcConn Connection con, String id) throws SQLException {
        return makeSessionHospital(hospitalDao.query(con, id));
    }

    @Path("/pq")
    @Get
    public PageQueryResult<SessionHospital> pageQuery(@JdbcConn Connection con, @Nullable Boolean active, @Nullable String addr, @Nullable String level, @Nullable String type, @Nullable String key, int pageSize, int pageNo) throws SQLException {
        PageQueryResult<Hospital> pageQueryResult = hospitalDao.pageQuery(con, addr == null ? null : addr + "%", active, level, type, key == null ? null : "%" + key + "%", pageSize, pageNo);
        if (pageQueryResult != null) {
            List<Hospital> hospitals = pageQueryResult.getData();
            List<SessionHospital> sessionHospitals = new ArrayList<>();
            if (!hospitals.isEmpty()) {
                for (Hospital hospital : hospitals) {
                    sessionHospitals.add(makeSessionHospital(hospital));
                }
                PageQueryResult<SessionHospital> ret = new PageQueryResult<>();
                ret.setPageNo(pageQueryResult.getPageNo());
                ret.setPageSize(pageQueryResult.getPageSize());
                ret.setTotal(pageQueryResult.getTotal());
                ret.setData(sessionHospitals);
                return ret;
            }
        }
        return null;
    }

    @Path("/city")
    @Get
    public List<Map<String, Object>> rank(@JdbcConn Connection con) throws SQLException {
        return JdbcUtil.queryList(con, "select substring(h.addr from 0 for 5) as city,count(*) as num from doctor d LEFT JOIN hospital h on d.hospital = h.id GROUP BY city ORDER BY num DESC", new ResultSetExtractor<Map<String, Object>>() {
            @Override
            public Map<String, Object> extractData(ResultSet resultSet) throws SQLException {
                Map<String, Object> map = new HashMap<>();
                map.put("city", resultSet.getString(1));
                map.put("num", resultSet.getInt(2));
                return map;
            }
        });
    }


    private static SessionHospital makeSessionHospital(Hospital hospital) {
        SessionHospital sessionHospital = new SessionHospital();
        sessionHospital.setAccount(hospital.getAccount());
        sessionHospital.setName(hospital.getName());
        sessionHospital.setLevel(hospital.getLevel());
        sessionHospital.setSubLevel(hospital.getSubLevel());
        sessionHospital.setId(hospital.getId());
        sessionHospital.setType(hospital.getType());
        sessionHospital.setPhone(hospital.getPhone());
        sessionHospital.setLocation(hospital.getLocation());
        sessionHospital.setAddr(hospital.getAddr());
        sessionHospital.setDescp(hospital.getDescp());
        sessionHospital.setImage(hospital.getImage());
        sessionHospital.setActive(hospital.isActive());
        sessionHospital.setCreateTime(hospital.getCreateTime());
        sessionHospital.setModifyTime(hospital.getModifyTime());
        sessionHospital.setCreator(hospital.getCreator());
        sessionHospital.setModifier(hospital.getModifier());
        return sessionHospital;
    }
}
